/**
 * This ast walker unparses the AST.  
 */
import java.io.PrintStream;
import ast.visitor.DepthFirstVisitor;
import ast.node.*;

public class UnparseVisitor extends DepthFirstVisitor {
    private PrintStream out;

    /** Constructor takes a PrintStream, and stores in instance var. */
    public UnparseVisitor(PrintStream out) {
        this.out = out;
    }

    public void inProgram(Program node)
    {
    }

    public void outProgram(Program node)
    {
    }

    public void inStatementList(StatementList node)
    {
    }

    public void outStatementList(StatementList node)
    {
    }

    public void inPrintStatement(PrintStatement node)
    {
    }

    public void outPrintStatement(PrintStatement node)
    {
    }

    public void inIntegerExp(IntegerExp node)
    {
    }

    public void outIntegerExp(IntegerExp node)
    {
    }
    
    public void inMinusExp(MinusExp node)
    {
    }

    public void outMinusExp(MinusExp node)
    {
    }

    public void inMulExp(MulExp node)
    {
    }

    public void outMulExp(MulExp node)
    {
    }

    public void inPlusExp(PlusExp node)
    {
    }

    public void outPlusExp(PlusExp node)
    {
    }
}

