/**
 *  Visitor class with a method to visit each AST node type.
 *  All implementations in this file call a defaultVisit method.
 */

package ast.visitor;

import ast.node.*;

public class Visitor
{
    public void defaultVisit(@SuppressWarnings("unused") Node node)
    {
        // do nothing
    }

    public void visitProgram(Program node)
    {
        defaultVisit(node);
    }

    public void visitStatementList(StatementList node)
    {
        defaultVisit(node);
    }

    public void visitPrintStatement(PrintStatement node)
    {
        defaultVisit(node);
    }

    public void visitMinusExp(MinusExp node)
    {
        defaultVisit(node);
    }

    public void visitMulExp(MulExp node)
    {
        defaultVisit(node);
    }
    
    public void visitPlusExp(PlusExp node)
    {
        defaultVisit(node);
    }

    public void visitIntegerExp(IntegerExp node)
    {
        defaultVisit(node);
    }
}
